@@ -68,6 +68,8 @@ import com.eteks.textureslibraryeditor.model.TexturesLibraryUserPreferences;
 public class TexturesLibraryFileRecorder implements TexturesLibraryRecorder {
   private static final Locale DEFAULT_LOCALE = new Locale("");
   
+  private static final String ID          = "id"; 
+  private static final String NAME        = "name"; 
   private static final String DESCRIPTION = "description"; 
   private static final String VERSION     = "version"; 
   private static final String LICENSE     = "license"; 
@@ -99,6 +101,8 @@ public class TexturesLibraryFileRecorder implements TexturesLibraryRecorder {
                                                URL texturesCatalogUrl,
                                                URL texturesResourcesUrlBase) {
             if (index == 1) {
+              texturesLibrary.setId(getOptionalString(resource, ID));
+              texturesLibrary.setName(getOptionalString(resource, NAME));
               texturesLibrary.setDescription(getOptionalString(resource, DESCRIPTION));
               texturesLibrary.setVersion(getOptionalString(resource, VERSION));
               texturesLibrary.setLicense(getOptionalString(resource, LICENSE));
@@ -216,7 +220,7 @@ public class TexturesLibraryFileRecorder implements TexturesLibraryRecorder {
    *                       if <code>texturesResourcesLocalDirectory</code> isn't <code>null</code>              
    */
   private void writeTexturesLibrary(TexturesLibrary texturesLibrary,
-                                     String texturesLibraryName,
+                                     String texturesLibraryLocation,
                                      boolean offlineTexturesLibrary,
                                      boolean contentMatchingTexturesName,
                                      String  texturesResourcesLocalDirectory,
@@ -242,7 +246,7 @@ public class TexturesLibraryFileRecorder implements TexturesLibraryRecorder {
     
     ZipOutputStream zipOut = null;
     Map<Content, String> contentEntries = new HashMap<Content, String>();
-    File texturesLibraryFile = new File(texturesLibraryName);
+    File texturesLibraryFile = new File(texturesLibraryLocation);
     File tmpFile = null;
     try {
       tmpFile = File.createTempFile("temp", ".sh3t"); 
@@ -276,13 +280,13 @@ public class TexturesLibraryFileRecorder implements TexturesLibraryRecorder {
         tmpFile.delete();
       }
     } catch (IOException ex) {
-      throw new RecorderException("Can't save textures library file " + texturesLibraryName, ex);
+      throw new RecorderException("Can't save textures library file " + texturesLibraryLocation, ex);
     } finally {
       if (zipOut != null) {
         try {
           zipOut.close();
         } catch (IOException ex) {
-          throw new RecorderException("Can't close textures library file " + texturesLibraryName, ex);
+          throw new RecorderException("Can't close textures library file " + texturesLibraryLocation, ex);
         }
       }
     }
@@ -310,6 +314,8 @@ public class TexturesLibraryFileRecorder implements TexturesLibraryRecorder {
         + "# Generated by Textures Library Editor\n#\n";
     writer.write(String.format(CATALOG_FILE_HEADER, new Date()));
     writer.newLine();
+    writeProperty(writer, ID, texturesLibrary.getId());
+    writeProperty(writer, NAME, texturesLibrary.getName());
     writeProperty(writer, DESCRIPTION, texturesLibrary.getDescription());
     writeProperty(writer, VERSION, texturesLibrary.getVersion());
     writeProperty(writer, LICENSE, texturesLibrary.getLicense());
